@@ -78,8 +78,10 @@ class TestHA(manager_congress.ScenarioPolicyBase):
         index = conf.find('[DEFAULT]') + len('[DEFAULT]\n')
         conf = (conf[:index] +
                 'bind_port = %d\n' % port_num +
-                'datasource_sync_period = 5\n' +
                 conf[index:])
+        # set datasource sync period interval to 5
+        conf = conf.replace('datasource_sync_period = 30',
+                            'datasource_sync_period = 5')
         sindex = conf.find('signing_dir')
         conf = conf[:sindex] + '#' + conf[sindex:]
         conf = conf + '\n[dse]\nbus_id = replica-node\n'
@@ -93,6 +95,7 @@ class TestHA(manager_congress.ScenarioPolicyBase):
         data = self.start_service('datasources', conf_file)
 
         assert port_num not in self.replicas
+        LOG.debug("successfully started replica services\n")
         self.replicas[port_num] = ([api, pe, data], conf_file)
 
     def start_service(self, name, conf_file):
@@ -140,6 +143,7 @@ class TestHA(manager_congress.ScenarioPolicyBase):
         try:
             LOG.debug("Check replica server status")
             client.list_policy()
+            LOG.debug("replica server ready")
             return True
         except exceptions.Unauthorized:
             LOG.debug("connection refused")
@@ -212,30 +216,19 @@ class TestHA(manager_congress.ScenarioPolicyBase):
             self.start_replica(CONF.congressha.replica_port)
             replica_client = self.create_client(CONF.congressha.replica_type)
 
-            # Verify that primary server synced fake dataservice and policy
-            if not test_utils.call_until_true(
-                    func=lambda: self._check_resource_exists(
-                        self.client, 'datasource'),
-                    duration=60, sleep_for=1):
-                raise exceptions.TimeoutException(
-                    "primary doesn't have fake dataservice, data sync failed")
-            if not test_utils.call_until_true(
-                    func=lambda: self._check_resource_exists(
-                        self.client, 'policy'),
-                    duration=60, sleep_for=1):
-                raise exceptions.TimeoutException(
-                    "primary doesn't have fake policy, policy sync failed")
-
             # Check replica server status
             if not test_utils.call_until_true(
                     func=lambda: self._check_replica_server_status(
                         replica_client),
                     duration=60, sleep_for=1):
                 raise exceptions.TimeoutException("Replica Server not ready")
-
             # Relica server is up
             replica_server = True
 
+            # primary server might sync later than replica server due to
+            # diff in datasource sync interval(P-30, replica-5). So checking
+            # replica first
+
             # Verify that replica server synced fake dataservice and policy
             if not test_utils.call_until_true(
                     func=lambda: self._check_resource_exists(
@@ -250,26 +243,24 @@ class TestHA(manager_congress.ScenarioPolicyBase):
                 raise exceptions.TimeoutException(
                     "replica doesn't have fake policy, policy sync failed")
 
+            # Verify that primary server synced fake dataservice and policy
+            if not test_utils.call_until_true(
+                    func=lambda: self._check_resource_exists(
+                        self.client, 'datasource'),
+                    duration=90, sleep_for=1):
+                raise exceptions.TimeoutException(
+                    "primary doesn't have fake dataservice, data sync failed")
+            if not test_utils.call_until_true(
+                    func=lambda: self._check_resource_exists(
+                        self.client, 'policy'),
+                    duration=90, sleep_for=1):
+                raise exceptions.TimeoutException(
+                    "primary doesn't have fake policy, policy sync failed")
+
             # Remove fake from primary server instance.
             LOG.debug("removing fake datasource %s", str(fake_id))
             self.client.delete_datasource(fake_id)
 
-            # Verify that primary server has no fake datasource and fake policy
-            if not test_utils.call_until_true(
-                    func=lambda: self._check_resource_missing(
-                        self.client, 'datasource'),
-                    duration=60, sleep_for=1):
-                raise exceptions.TimeoutException(
-                    "primary still has fake dataservice, sync failed")
-            if not test_utils.call_until_true(
-                    func=lambda: self._check_resource_missing(
-                        self.client, 'policy'),
-                    duration=60, sleep_for=1):
-                raise exceptions.TimeoutException(
-                    "primary still fake policy, policy synchronizer failed")
-
-            LOG.debug("removed fake datasource from primary instance")
-
             # Verify that replica server has no fake datasource and fake policy
             if not test_utils.call_until_true(
                     func=lambda: self._check_resource_missing(
@@ -284,6 +275,24 @@ class TestHA(manager_congress.ScenarioPolicyBase):
                 raise exceptions.TimeoutException(
                     "replica still fake policy, policy synchronizer failed")
 
+            LOG.debug("removed fake datasource from replica instance")
+
+            # Verify that primary server has no fake datasource and fake policy
+            if not test_utils.call_until_true(
+                    func=lambda: self._check_resource_missing(
+                        self.client, 'datasource'),
+                    duration=90, sleep_for=1):
+                raise exceptions.TimeoutException(
+                    "primary still has fake dataservice, sync failed")
+            if not test_utils.call_until_true(
+                    func=lambda: self._check_resource_missing(
+                        self.client, 'policy'),
+                    duration=90, sleep_for=1):
+                raise exceptions.TimeoutException(
+                    "primary still fake policy, policy synchronizer failed")
+
+            LOG.debug("removed fake datasource from primary instance")
+
         finally:
             if replica_server:
                 self.stop_replica(CONF.congressha.replica_port)
